@@ -1,6 +1,6 @@
 /*
 * this file is part of the oxygen gtk engine
-* Copyright (c) 2010 Hugo Pereira Da Costa <hugo@oxygen-icons.org>
+* Copyright (c) 2010 Hugo Pereira Da Costa <hugo.pereira@free.fr>
 *
 * This  library is free  software; you can  redistribute it and/or
 * modify it  under  the terms  of the  GNU Lesser  General  Public
@@ -73,12 +73,17 @@ namespace Oxygen
 
         #if OXYGEN_DEBUG
         std::cerr << "DialogEngine::registerWidget - numOfResponsesFound: " << numOfResponsesFound << std::endl;
-        for(int i=0; i<numOfResponseIDs; i++)
-        {
-            std::cerr << Gtk::TypeNames::response( responses[i] ) << ", ";
-            if(i==numOfResponsesFound-1) std::cerr<<"_END_of_found_,";
-        }
-        std::cerr << "\n\n";
+        std::cerr << "List of responses found: { ";
+
+        for(int i=0; i<numOfResponsesFound; i++)
+        { std::cerr << Gtk::TypeNames::response( responses[i] ) << (i==numOfResponsesFound-1 ? " " :", "); }
+
+        std::cerr << "}; remaining in the list: { ";
+
+        for(int i=numOfResponsesFound; i<numOfResponseIDs; i++)
+        { std::cerr << Gtk::TypeNames::response( responses[i] ) << (i==numOfResponseIDs-1 ? " " :", "); }
+
+        std::cerr << "}\n";
         #endif
 
         // change order
