@@ -1,6 +1,6 @@
 /*
 * this file is part of the oxygen gtk engine
-* Copyright (c) 2010 Hugo Pereira Da Costa <hugo@oxygen-icons.org>
+* Copyright (c) 2010 Hugo Pereira Da Costa <hugo.pereira@free.fr>
 *
 * This  library is free  software; you can  redistribute it and/or
 * modify it  under  the terms  of the  GNU Lesser  General  Public
@@ -35,7 +35,7 @@ namespace Oxygen
     }
 
     //________________________________________________________________________________
-    void ScrollBarData::disconnect( GtkWidget* widget )
+    void ScrollBarData::disconnect( GtkWidget* )
     {
         _target = 0L;
 
