@@ -2,7 +2,7 @@
 #define oxygenapplicationname_h
 /*
 * this file is part of the oxygen gtk engine
-* Copyright (c) 2010 Hugo Pereira Da Costa <hugo@oxygen-icons.org>
+* Copyright (c) 2010 Hugo Pereira Da Costa <hugo.pereira@free.fr>
 *
 * inspired notably from kdelibs/kdeui/color/kcolorutils.h
 * Copyright (C) 2007 Matthew Woehlke <mw_triad@users.sourceforge.net>
@@ -55,7 +55,8 @@ namespace Oxygen
 
         //! constructor
         ApplicationName( AppName name = Unknown ):
-            _name( name )
+            _name( name ),
+            _version( NULL )
         {}
 
         //! assignment
@@ -69,6 +70,9 @@ namespace Oxygen
         operator const AppName& ( void ) const
         { return _name; }
 
+        const char* versionString( void ) const
+        { return _version; }
+
         //! initialize
         /*! try derive AppName from gtk program name */
         void initialize( void );
@@ -116,6 +120,8 @@ namespace Oxygen
         //! name
         AppName _name;
 
+        const char* _version;
+
         //! streamer (for debugging)
         friend std::ostream& operator << ( std::ostream&, const ApplicationName& );
 
