@@ -2,7 +2,7 @@
 #define oxygenstylehelper_h
 /*
 * this file is part of the oxygen gtk engine
-* Copyright (c) 2010 Hugo Pereira Da Costa <hugo@oxygen-icons.org>
+* Copyright (c) 2010 Hugo Pereira Da Costa <hugo.pereira@free.fr>
 *
 * This  library is free  software; you can  redistribute it and/or
 * modify it  under  the terms  of the  GNU Lesser  General  Public
@@ -201,6 +201,9 @@ namespace Oxygen
 
         //@}
 
+        //! window decorations button for MDI windows from oxygen-qt, used as tab close button in oxygen-gtk
+        const Cairo::Surface& dockWidgetButton(const ColorUtils::Rgba& base, bool pressed, int size);
+
         protected:
 
         //! access reference surface
@@ -303,6 +306,9 @@ namespace Oxygen
         //! window backgound radial gradient
         CairoSurfaceCache<RadialGradientKey> _radialGradientCache;
 
+        //! dock widget button
+        CairoSurfaceCache<DockWidgetButtonKey> _dockWidgetButtonCache;
+
         //@}
 
         //!@name windeco borders
